@@ -18,7 +18,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 26 May 2012                                              }
+{ last modified: 23 Oct 2012                                              }
 {*************************************************************************/
 
 #include "alkatraz.h"
@@ -40,12 +40,7 @@ QString md5(const QString& s)
 
 QString randomHash()
 {
-    QString s;
-    s.setNum(qrand());
-    QString s1;
-    s1.setNum(QDateTime::currentMSecsSinceEpoch());
-    s.append(s1);
-    return md5(s);
+    return md5(QString::number(qrand())+QString::number(QDateTime::currentMSecsSinceEpoch()));
 }
 
 void sleep(int msecs)
@@ -75,6 +70,33 @@ void* safeRealloc(void* mem, qint32 size)
     }
 }
 
+QString ErrorHandler::errorCodeToString(int errorCode)
+{
+    if(errorCode == err_NoError)
+        return "No Error";
+    else
+        return "";
+}
+
+QString ErrorHandler::errorDataToString(int errorCode, const void *data)
+{
+    Q_UNUSED(errorCode);
+    Q_UNUSED(data);
+    return "";
+}
+
+QString ErrorHandler::errorToString(int errorCode, const void *data)
+{
+    QString errString = errorCodeToString(errorCode);
+    if(errString.isEmpty())
+        return errString;
+    QString dataString = errorDataToString(errorCode, data);
+    if(dataString.isEmpty())
+        return errString;
+    else
+        return errString+": "+dataString;
+}
+
 #ifdef QT_GUI_LIB
 QStringList wordwrap(const QString& text, int maxWidth, const QFontMetrics &fontMetrics)
 {
