@@ -18,7 +18,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 26 May 2012                                              }
+{ last modified: 16 Nov 2012                                              }
 {*************************************************************************/
 
 #ifndef ALKATRAZ_H
@@ -34,7 +34,11 @@
     #include <e32const.h>
 #endif
 
-#define SETERROR(err, data...) lastError=err; emit onError(err, ## data)
+#define __SETERROR_NODATA(err) {lastError = err; emit onError(this, __FILE__, __LINE__, err, NULL);}
+#define __SETERROR_DATA(err, data) {lastError = err; emit onError(this, __FILE__, __LINE__, err, data);}
+#define __SETERROR_CHOOSER(__ARG1, __ARG2, __F, ...) __F
+#define SETERROR(...) __SETERROR_CHOOSER(__VA_ARGS__, __SETERROR_DATA(__VA_ARGS__), __SETERROR_NODATA(__VA_ARGS__))
+
 #define CHECK(s, err, data...) if(!(s)) {SETERROR(err, ## data); return false;}
 #define CHECKV(s, err, data...) if(!(s)) {SETERROR(err, ## data); return;}
 #define CHECKB(s, err, data...) if(!(s)) {SETERROR(err, ## data); break;}
@@ -55,7 +59,7 @@
 #ifdef Q_OS_SYMBIAN
         const int MAX_PATH_LENGTH = KMaxPath;
 #else
-    #ifdef WIN32
+    #ifdef Q_OS_WIN
         const int MAX_PATH_LENGTH = MAX_PATH;
     #else
         const int MAX_PATH_LENGTH = 255; // stub for others
@@ -71,6 +75,10 @@ public:
     explicit ErrorHandler(){resetLastError();}
     inline int getLastError() const {return lastError;}
     inline void resetLastError(){lastError=err_NoError;}
+
+    static QString errorCodeToString(int errorCode);
+    static QString errorDataToString(int errorCode, const void* data);
+    static QString errorToString(int errorCode, const void* data);
 };
 
 void randomize();
@@ -78,7 +86,7 @@ inline int rnd(quint32 limit){return qrand()%limit;}
 QString md5(const QString& s);
 QString randomHash();
 
-inline int sgn(quint32 val)
+inline int sgn(qint32 val)
 {
     if(val>0)return 1;
     if(val==0)return 0;
@@ -92,4 +100,9 @@ void* safeRealloc(void* mem, qint32 size);
 QStringList wordwrap(const QString& text, int maxWidth, const QFontMetrics& fontMetrics);
 #endif
 
+inline QString getParentDir(const QString &path)
+{
+    return (QFileInfo(path)).absoluteDir().absolutePath();
+}
+
 #endif // ALKATRAZ_H
