@@ -18,7 +18,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 May 2012                                              }
+{ last modified: 13 Sep 2012                                              }
 {*************************************************************************/
 
 #include "qkineticwidget.h"
@@ -49,15 +49,33 @@ QKineticWidget::QKineticWidget(QWidget *parent) :
     activeWidget = NULL;
     cssNormal = "";
     cssActive = "";
-    setTimerInterval(20);
+    timerInterval = 20;
+    start();
 }
 
 void QKineticWidget::setTimerInterval(int msecs)
 {
-    if(timer)
-        killTimer(timer);
-    timer = startTimer(msecs);
     timerInterval = msecs;
+    if(timer)
+    {
+        stop();
+        start();
+    }
+}
+
+void QKineticWidget::start()
+{
+    if(!timer)
+        timer = startTimer(timerInterval);
+}
+
+void QKineticWidget::stop()
+{
+    if(timer)
+    {
+        killTimer(timer);
+        timer = 0;
+    }
 }
 
 void QKineticWidget::setInnerWidth(int value)
@@ -379,8 +397,7 @@ void QKineticWidget::scrollY(float offset)
 
 QKineticWidget::~QKineticWidget()
 {
-    if(timer)
-        killTimer(timer);
+    stop();
 }
 
 void QKineticWidget::deleteAllChildren()
