@@ -18,7 +18,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 29 May 2012                                              }
+{ last modified: 23 Oct 2012                                              }
 {*************************************************************************/
 
 #include "fsman.h"
@@ -44,8 +44,8 @@ bool caseInsensitiveLessThan(const QString &s1, const QString &s2)
 
 QString FSMan::which(const QString& program)
 {
-#ifdef WIN32
-    return FSMan::getShellCommandOutput("for %i in ("+program+".exe) do @echo.%~$PATH:i");
+#ifdef Q_OS_WIN
+    return FSMan::getShellCommandOutput("for %i in ("+program+".exe) do @echo.%~$PATH:i").trimmed();
 #else
     QStringList args;
     args.append(program);
@@ -218,7 +218,7 @@ QString FSMan::getParentDir(const QString& dirPath)
     result = dirPath.left(a);
     if(result.isEmpty())
     {
-#ifdef WIN32
+#ifdef Q_OS_WIN
         return dirPath.at(0)+':';
 #else
         return "/";
@@ -232,7 +232,7 @@ QString FSMan::getParentDir(const QString& dirPath)
 
 void FSMan::setUsingNativeMethods(bool doUse)
 {
-#ifndef WIN32
+#ifndef Q_OS_WIN
     doUseNativeMethods = doUse;
 #else
     Q_UNUSED(doUse);
@@ -241,7 +241,7 @@ void FSMan::setUsingNativeMethods(bool doUse)
 
 bool FSMan::isDirAccessible(const QString& dirPath, bool useNativeMethod)
 {
-#ifndef WIN32
+#ifndef Q_OS_WIN
     if(useNativeMethod)
     {
         QString command = "\
@@ -258,7 +258,7 @@ fi\n";
         QDir dir;
         bool result = dir.cd(dirPath);
         return result;
-#ifndef WIN32
+#ifndef Q_OS_WIN
     }
 #endif
 }
@@ -267,7 +267,7 @@ QString FSMan::getShellCommandOutput(const QString& cmd)
 {
     QStringList args;
     QString shell;
-#ifdef WIN32
+#ifdef Q_OS_WIN
     shell = "cmd";
     args.append("/c");
 #else
@@ -280,12 +280,11 @@ QString FSMan::getShellCommandOutput(const QString& cmd)
 
 QString FSMan::shellEscape(const QString& line)
 {
-#ifdef WIN32
+#ifdef Q_OS_WIN
     return line;
 #endif
     QByteArray bytes = line.toUtf8();
     QString result;
-    QString byteCode;
     int n = bytes.size();
     int realCode;
     for(int a=0; a<n; a++)
@@ -293,8 +292,7 @@ QString FSMan::shellEscape(const QString& line)
         realCode = bytes.at(a);
         if(realCode<0)
             realCode = realCode + 256;
-        byteCode.setNum(realCode, 16);
-        result += "\\x"+byteCode;
+        result += "\\x"+QString::number(realCode, 16);
     }
     return result;
 }
@@ -302,7 +300,7 @@ QString FSMan::shellEscape(const QString& line)
 bool FSMan::_removeFile(const QString &filename, bool useNativeMethod, FSManCache* _cache)
 {
     bool result;
-#ifndef WIN32
+#ifndef Q_OS_WIN
     if(useNativeMethod)
     {
         QString command = "rm -f `echo -e \""+shellEscape(filename)+"\"`";
@@ -348,8 +346,8 @@ bool FSMan::_removeDir(const QString &dirname, bool useNativeMethod, FSManCache*
             return false;
     }
 
-#ifndef WIN32
     bool result;
+#ifndef Q_OS_WIN
     if(useNativeMethod)
     {
         QString command = "rm -rf `echo -e \""+shellEscape(dirname)+"\"`";
@@ -384,7 +382,7 @@ void FSMan::startSearch(const QString &expression, const QString startDir)
         _dir = curDir;
     if(_dir.isEmpty())
     {
-#ifdef Q_OS_WIN32
+#ifdef Q_OS_WIN
         _dir = "C:/";
 #else
         _dir = "/";
@@ -409,7 +407,7 @@ void FSMan::ls(const QString& path, QStringList& dirsList, QStringList& filesLis
 {
     dirsList.clear();
     filesList.clear();
-#ifndef WIN32
+#ifndef Q_OS_WIN
     if(useNativeMethod)
     {
         QString command = "\
@@ -455,13 +453,32 @@ done\n";
             else
                 filesList.append(entry.fileName());
         }
-#ifndef WIN32
+#ifndef Q_OS_WIN
     }
 #endif
     qSort(dirsList.begin(), dirsList.end(), caseInsensitiveLessThan);
     qSort(filesList.begin(), filesList.end(), caseInsensitiveLessThan);
 }
 
+QString FSMan::getHomeDir()
+{
+    QString homeDir;
+#ifdef QT_GUI_LIB
+    homeDir = QDesktopServices::storageLocation(QDesktopServices::HomeLocation);
+#else
+    #ifdef Q_OS_WIN
+        homeDir = getShellCommandOutput("echo %HOMEDRIVE%%HOMEPATH%").trimmed();
+        if(homeDir.isEmpty())
+            homeDir = "C:/";
+    #else
+        homeDir = getShellCommandOutput("echo ~").trimmed();
+        if(homeDir.isEmpty())
+            homeDir = "/";
+    #endif
+#endif
+   return homeDir;
+}
+
 bool FSMan::getRawProcessOutput(QByteArray& dest, const QString& cmd, const QStringList& args)
 {
     QProcess proc;
