@@ -18,13 +18,16 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 29 May 2012                                              }
+{ last modified: 19 Oct 2012                                              }
 {*************************************************************************/
 
 #ifndef FSMAN_H
 #define FSMAN_H
 
 #include <QtCore>
+#ifdef QT_GUI_LIB
+#include <QtGui>
+#endif
 
 typedef struct {
     QStringList files;
@@ -101,6 +104,8 @@ public:
     static void ls(const QString& path, QStringList& dirsList, QStringList& filesList, bool useNativeMethod);
     inline void ls(const QString& path, QStringList& dirsList, QStringList& filesList){ls(path, dirsList, filesList, doUseNativeMethods);}
 
+    static QString getHomeDir();
+
     static bool getRawProcessOutput(QByteArray& dest, const QString& cmd, const QStringList& args = QStringList());
     static QString getProcessOutput(const QString& cmd, const QStringList& args);
     static QString getProcessOutput(const QString& cmd);
