@@ -18,7 +18,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                              }
+{ last modified: 04 Sep 2012                                              }
 {*************************************************************************/
 
 #ifndef QWIDGETHELPER_H
@@ -36,10 +36,18 @@ enum ScreenOrientation {
 class QWidgetHelper
 {
 public:
-    void setupDefaults();
-    void fullyActivate();
-    void setScreenOrientation(ScreenOrientation orientation);
-    void showExpanded();
+    inline void setupDefaults(){setupDefaults((QWidget*)this);}
+    inline void fullyActivate(){fullyActivate((QWidget*)this);}
+    inline void setScreenOrientation(ScreenOrientation orientation){setScreenOrientation((QWidget*)this, orientation);}
+    inline void showExpanded(){showExpanded((QWidget*)this);}
+
+    static void setupDefaults(QWidget* widget);
+    static void fullyActivate(QWidget* widget);
+    static void setScreenOrientation(QWidget* widget, ScreenOrientation orientation);
+    static void showExpanded(QWidget* widget);
+
+    static bool simpleResize(QResizeEvent* event, int &width, int &height);
+    static bool maximizedAutoResize(QWidget* widget, QResizeEvent* event);
 };
 
 #endif // QWIDGETHELPER_H
