@@ -26,19 +26,13 @@
 
 #include "app.h"
 
-App::App(int &argc, char **argv) : QApplication(argc, argv)
+App::App(int &argc, char **argv) : CoreApp(argc, argv)
 {
-    randomize();
-    init();
-    loadTranslators();
-    createUi();
+    exitAfterMain = false;
 }
 
 void App::init()
 {
-    setApplicationName(APP_NAME);
-    setApplicationVersion(APP_VERSION);
-
     QDir::setCurrent(applicationDirPath());
 
 #ifndef MAEMO5
@@ -46,6 +40,15 @@ void App::init()
 #endif
 }
 
+int App::main()
+{
+    randomize();
+    init();
+    loadTranslators();
+    createUi();
+    return 0;
+}
+
 void App::loadTranslators()
 {
     QString localeName = QLocale::system().name();
