@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 21 May 2012                                              }
+{ last modified: 27 Nov 2012                                              }
 {*************************************************************************/
 
 #include "equalizer.h"
@@ -212,13 +212,9 @@ QString Equalizer::getPresetIniKey(const QString &presetName)
 void Equalizer::saveArrayToPreset(const double *levels, const QString &presetName)
 {
     QStringList lines;
-    QString num;
     QString line;
     for(int a=0; a<bandsCount; a++)
-    {
-        num.setNum(levels[a], 'f');
-        lines.append(num);
-    }
+        lines.append(QString::number(levels[a], 'f'));
     line = lines.join(";");
     ini->setValue(getPresetIniKey(presetName), line);
 }
