@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                              }
+{ last modified: 21 May 2012                                              }
 {*************************************************************************/
 
 #ifndef EQUALIZER_H
@@ -47,13 +47,13 @@ public:
     inline double getBandUpperBound(int bandIndex) const {return bandUpperBounds[bandIndex];}
     inline double getBandLowerBound(int bandIndex) const {return bandLowerBounds[bandIndex];}
     inline double getBandLevel(int bandIndex) const {return bandLevels[bandIndex];}
-    double setBandLevel(int bandIndex, double newLevel);
 
-    double setDefaultBandLevel(int bandIndex);
+    void setDefaultBandLevel(int bandIndex);
     void setDefaultLevels();
     double getRealBandLevel(int bandIndex);
     double updateLevel(int bandIndex);
     void updateLevels();
+    void copyLevels(Equalizer* eq);
 
     inline Phonon::Effect* getEffect() {return effect;}
 
@@ -89,6 +89,12 @@ protected:
     QString getPresetIniKey(const QString& presetName);
     void saveArrayToPreset(const double* levels, const QString& presetName);
     bool loadArrayFromPreset(double* levels, const QString& presetName);
+
+public slots:
+    void setBandLevel(int bandIndex, double newLevel);
+
+signals:
+    void onBandLevelChange(int bandIndex, double newLevel);
 };
 
 #endif // EQUALIZER_H
