@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 06 Jun 2012                                              }
+{ last modified: 27 Nov 2012                                              }
 {*************************************************************************/
 
 #include "equalizerwindow.h"
@@ -90,8 +90,7 @@ void EqualizerWindow::initGui()
         f = eq()->getBandFrequency(a);
         if(f<1000)
         {
-            s.setNum(f);
-            s.append(tr("Hz"));
+            s = QString::number(f)+tr("Hz");
         }
         else
         {
