@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 May 2012                                              }
+{ last modified: 05 Dec 2012                                              }
 {*************************************************************************/
 
 #include "mainwindow.h"
@@ -40,6 +40,7 @@ MainWindow::MainWindow(QWidget *parent) :
     errCount = 0;
     timerId = 0;
     timerMinsLeft = -1;
+    autoScrollOnRestoreY = false;
 
     QFont f = font();
     f.setFamily("Arial");
@@ -80,7 +81,7 @@ MainWindow::MainWindow(QWidget *parent) :
     // jump to currently selected folder or file if any,
     // but at start, size() is messed up and so is itemsContainer's height,
     // so call this routine with a small delay
-    QTimer::singleShot(500, this, SLOT(jumpToCurrentItem()));
+    QTimer::singleShot(1000, this, SLOT(jumpToCurrentItem()));
 }
 
 MainWindow::~MainWindow()
@@ -442,7 +443,11 @@ void MainWindow::updateListIcons(bool playMode)
         currentDirItem = NULL;
     }
 
-    if(filename.startsWith(fs->getCurrentDirectory()))
+    QString dirName = fs->getCurrentDirectory();
+    if(!dirName.endsWith("/"))
+        dirName.append("/");
+
+    if(filename.startsWith(dirName))
     {
         foreach(QObject* child, itemsContainer->children())
         {
@@ -451,7 +456,7 @@ void MainWindow::updateListIcons(bool playMode)
             {
                 if(item->getBool())
                 {
-                    if(filename.startsWith(item->getString()))
+                    if(filename.startsWith(item->getString()+"/"))
                     {
                         currentDirItem = item;
                         item->setIcon(skin->icoFolderPlay);
@@ -575,7 +580,23 @@ void MainWindow::restoreY()
 {
     const QString& dir = fs->getCurrentDirectory();
     if(yCache.contains(dir))
+    {
         itemsContainer->setY(yCache[dir]);
+    }
+    else
+    {
+        if(autoScrollOnRestoreY)
+        {
+            if(currentDirItem)
+                itemsContainer->centerWidgetV(currentDirItem);
+            else if(currentFileItem)
+                itemsContainer->centerWidgetV(currentFileItem);
+        }
+        else
+        {
+            autoScrollOnRestoreY = true;
+        }
+    }
 }
 
 void MainWindow::openInis()
@@ -655,7 +676,9 @@ void MainWindow::onItemClick(QWidget *item)
         {
             checkTimerCancel();
             if(currentFileItem == theItem)
+            {
                 onBtnPlayClick(); // clicked on the current file
+            }
             else
             {
                 queue.clear();
@@ -827,15 +850,12 @@ void MainWindow::onTitleChange()
         // all that nonsense below is just for fitting all the text in notification window
         // this circumvents a weird text cropping in such windows on Maemo
         const QString& title = player->getTitle();
-        QString cur, tot;
-        cur.setNum(currentFileIndex+1);
-        tot.setNum(playlist.size());
         QFileInfo info(getCurrentFilename());
         QString path = QDir::cleanPath(info.absolutePath());
         int n = path.lastIndexOf("/");
         path.remove(0, n+1);
         int w = width() - 50; // guessing notification popup space width, allowed for text
-        QString s = cur+"/"+tot+" - ["+path+"]";
+        QString s = QString::number(currentFileIndex+1)+"/"+QString::number(playlist.size())+" - ["+path+"]";
         QStringList dirLines = wordwrap(s, w, *notificationMetrics);
         QStringList titleLines = wordwrap(title, w, *notificationMetrics);
         s = dirLines.join("\n")+"\n"+titleLines.join("\n");
@@ -962,8 +982,7 @@ void MainWindow::onMenuFolderAllAddClick()
     playlist.removeDuplicates();
     n = playlist.size() - n;
     QString s;
-    s.setNum(playlist.size());
-    s = QString("\n")+tr("total files count")+": "+s;
+    s = QString("\n")+tr("total files count")+": "+QString::number(playlist.size());
     if(n)
         s.prepend(tr("added %n more file(s)", "", n));
     else
@@ -989,10 +1008,9 @@ void MainWindow::onMenuFileSetNextClick()
 void MainWindow::onMenuFileAddQueueClick()
 {
     queue.append(contextMenuOwner->getString());
-    QString s;
-    s.setNum(queue.size());
-    s.prepend(tr("files queued")+": ");
-    showNotification(tr("this file has been added to queue")+"\n"+s);
+    showNotification(
+                tr("this file has been added to queue")+"\n"+
+                tr("files queued")+": "+QString::number(queue.size()));
     if(queue.size() == 1)
         cacheNext();
 }
@@ -1411,12 +1429,9 @@ void MainWindow::updateTimerActionLabel()
     {
         int digits[4];
         TimerWindow::minsToDigits(timerMinsLeft, &digits[0]);
-        QString tmp;
-        tmp.setNum(digits[3]);s.append(tmp);
-        tmp.setNum(digits[2]);s.append(tmp);
-        s.append(":");
-        tmp.setNum(digits[1]);s.append(tmp);
-        tmp.setNum(digits[0]);s.append(tmp);
+        s.append(
+            QString::number(digits[3])+QString::number(digits[2])+":"+
+            QString::number(digits[1])+QString::number(digits[0]));
     }
     actionTimer->setText(s);
 }
