@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 May 2012                                              }
+{ last modified: 05 Dec 2012                                              }
 {*************************************************************************/
 
 #ifndef MAINWINDOW_H
@@ -131,6 +131,7 @@ protected:
     QString appDir;
     QStringList queue;
     KineticListItem* contextMenuOwner;
+    bool autoScrollOnRestoreY;
 
     int timerId;
     int timerMinsLeft;
