@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 May 2012                                              }
+{ last modified: 06 Jun 2012                                              }
 {*************************************************************************/
 
 #include "searchwindow.h"
@@ -60,7 +60,7 @@ void SearchWindow::showSearchWindow(const QString& txt)
     SearchWindow* win = new SearchWindow(MAINWINDOW);
     win->editExp->setText(txt.trimmed());
     win->setFocusToEdit(-2);
-    win->showDialog();
+    win->showDialog(ScreenOrientationLockLandscape);
     delete win;
 }
 
