@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 May 2012                                              }
+{ last modified: 27 Nov 2012                                              }
 {*************************************************************************/
 
 #include "spinnumber.h"
@@ -82,16 +82,12 @@ void SpinNumber::resizeEvent(QResizeEvent *event)
     int bx = (label->width()-btnUp->width())/2;
     btnUp->move(bx, label->height());
     btnDown->move(bx, h - btnUp->height() - CONTROLBUTTON_PUSHOFFSET);
-    QString s;
-    s.setNum(label->height());
-    label->setStyleSheet(QString("font-size:")+s+"px;");
+    label->setStyleSheet(QString("font-size:")+QString::number(label->height())+"px;");
 }
 
 void SpinNumber::updateDisplay()
 {
-    QString s;
-    s.setNum(value);
-    label->setText(s);
+    label->setText(QString::number(value));
 }
 
 void SpinNumber::cycleValue(int valueStep)
