@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                              }
+{ last modified: 31 May 2012                                              }
 {*************************************************************************/
 
 #ifndef SPINNUMBER_H
@@ -55,7 +55,7 @@ protected:
 
     Button* btnUp;
     Button* btnDown;
-    QLabel* label;
+    Label* label;
 
     int value;
     int minValue, maxValue;
