@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 25 Mar 2012                                              }
+{ last modified: 31 May 2012                                              }
 {*************************************************************************/
 
 #include "timerwindow.h"
@@ -94,12 +94,12 @@ void TimerWindow::initGui()
 
     int x = 10;
 
-    labelHrs = new QLabel(this);
+    labelHrs = new Label(this);
     labelHrs->setText(tr("hours"));
     labelHrs->setAlignment(Qt::AlignCenter);
     int h = labelHrs->fontMetrics().height();
     labelHrs->resize(10, h);
-    labelMins = new QLabel(this);
+    labelMins = new Label(this);
     labelMins->setText(tr("minutes"));
     labelMins->resize(10, h);
     labelMins->setAlignment(Qt::AlignCenter);
@@ -113,7 +113,7 @@ void TimerWindow::initGui()
 
     int w = x;
 
-    labelSep = new QLabel(this);
+    labelSep = new Label(this);
     labelSep->move(x, h);
     labelSep->setText(":");
     labelSep->setAlignment(Qt::AlignCenter);
