@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 25 Mar 2012                                              }
+{ last modified: 31 May 2012                                              }
 {*************************************************************************/
 
 #ifndef TIMERWINDOW_H
@@ -50,8 +50,8 @@ protected:
         *spinHrs, *spinHrsTens,
         *spinMins, *spinMinsTens;
 
-    QLabel *labelHrs, *labelMins;
-    QLabel* labelSep;
+    Label *labelHrs, *labelMins;
+    Label* labelSep;
     QPushButton* btnStart;
 
 protected slots:
